netapp_ontap.resources.multi_admin_verify_config API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.multi_admin_verify_config`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

These APIs provide information on the multi-admin verification global setting. The GET API retrieves the object store that contains the global setting values of the multi-admin-verify feature. The PATCH request is used to modify the multi-admin-verify global setting. All fields are optional for the PATCH request. Note it is recommended that multi-admin-verify is enabled equally on peered ONTAP clusters.

## Examples

### Retrieving the multi-admin-verify global setting

Retrieves the current multi-admin-verify global setting. If the global setting is not set, default values are returned.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import MultiAdminVerifyConfig

    with HostConnection(
        "<cluster-ip>", username="admin", password="password", verify=False
    ):
        resource = MultiAdminVerifyConfig()
        resource.get()
        print(resource)

Try it out

    MultiAdminVerifyConfig(
        {
            "required_approvers": 1,
            "approval_expiry": "PT1H",
            "approval_groups": [],
            "execution_expiry": "PT1H",
            "enabled": False,
        }
    )

### Updating the multi-admin-verify global setting

The following example updates the multi-admin-verify global settings. Note that the approval_groups needs to be available in /security/multi-admin-verify/approval-groups before it is set in the global setting. Note that the total number of approvers in an approval group must be a positive integer more than the number of required approvers. For example, if there are a total of 10 approvers in a group, the required approvers can be set between 1 and 9.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import MultiAdminVerifyConfig

    with HostConnection(
        "<cluster-ip>", username="admin", password="password", verify=False
    ):
        resource = MultiAdminVerifyConfig()
        resource.required_approvers = "1"
        resource.enabled = True
        resource.execution_expiry = "2h"
        resource.approval_expiry = "3h"
        resource.patch()

## Classes

`class MultiAdminVerifyConfig (*args, **kwargs)`

  Allows interaction with MultiAdminVerifyConfig objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves the multi-admin-verify configuration.

    ### Learn more

    - `DOC /security/multi-admin-verify`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Modifies the multi-admin-verify configuration.

    ### Learn more

    - `DOC /security/multi-admin-verify`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class MultiAdminVerifyConfigSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the MultiAdminVerifyConfig object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `approval_expiry: str GET POST PATCH`

    Default time for requests to be approved, in ISO-8601 duration format.

  `approval_groups: List[str] GET POST PATCH`

    List of approval groups that are allowed to approve requests for rules that don't have approval groups.

  `enabled: bool GET POST PATCH`

    The enabled field of the multi_admin_verify_config.

  `execution_expiry: str GET POST PATCH`

    Default time for requests to be executed once approved, in ISO-8601 duration format.

  `required_approvers: Size GET POST PATCH`

    The number of required approvers, excluding the user that made the request.